netapp_ontap.resources.lun API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.lun`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

A LUN is the logical representation of storage in a storage area network (SAN).
The LUN REST API allows you to create, update, delete, and discover LUNs.
In ONTAP, a LUN is located within a volume. Optionally, it can be located within a qtree in a volume.
A LUN can be created to a specified size using thin or thick provisioning. A LUN can then be renamed, resized, cloned, and moved to a different volume. LUNs support the assignment of a quality of service (QoS) policy for performance management or a QoS policy can be assigned to the volume containing the LUN. See the LUN object model to learn more about each of the properties supported by the LUN REST API.
A LUN must be mapped to an initiator group to grant access to the initiator group's initiators (client hosts). Initiators can then access the LUN and perform I/O over a Fibre Channel (FC) fabric using the FC Protocol or a TCP/IP network using iSCSI.

## Performance monitoring

Performance of a LUN can be monitored by observing the `metric.*` and `statistics.*` properties. These properties show the performance of a LUN in terms of IOPS, latency and throughput. The `metric.*` properties denote an average whereas `statistics.*` properies denote a real-time monotonically increasing value aggregated across all nodes.

## Examples

### Creating a LUN

This example creates a 300 gigabyte, thin-provisioned LUN in SVM svm1, volume vol1, configured for use by linux initiators. The `return_records` query parameter is used to retrieve properties of the newly created LUN in the POST response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun()
        resource.svm.name = "svm1"
        resource.os_type = "linux"
        resource.space.size = "300G"
        resource.name = "/vol/vol1/lun1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    Lun(
        {
            "os_type": "linux",
            "class": "regular",
            "uuid": "5a24ae5b-28af-47fb-b129-5adf6cfba0a6",
            "space": {
                "guarantee": {"requested": False, "reserved": False},
                "used": 0,
                "size": 322163441664,
            },
            "name": "/vol/vol1/lun1",
            "svm": {
                "uuid": "6bf967fd-2a1c-11e9-b682-005056bbc17d",
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/6bf967fd-2a1c-11e9-b682-005056bbc17d"}
                },
            },
            "status": {"read_only": False, "state": "online", "container_state": "online"},
            "serial_number": "wf0Iq+N4uck3",
            "location": {
                "volume": {
                    "uuid": "71cd0dba-2a1c-11e9-b682-005056bbc17d",
                    "name": "vol1",
                    "_links": {
                        "self": {
                            "href": "/api/storage/volumes/71cd0dba-2a1c-11e9-b682-005056bbc17d"
                        }
                    },
                },
                "logical_unit": "lun1",
            },
            "enabled": True,
            "_links": {
                "self": {"href": "/api/storage/luns/5a24ae5b-28af-47fb-b129-5adf6cfba0a6"}
            },
        }
    )

### Updating a LUN

This example sets the `comment` property of a LUN.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="5a24ae5b-28af-47fb-b129-5adf6cfba0a6")
        resource.comment = "Data for the finance department."
        resource.patch()

### Retrieving LUNs

This example retrieves summary information for all online LUNs in SVM svm1. The `svm.name` and `status.state` query parameters are used to find the desired LUNs.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Lun.get_collection(**{"svm.name": "svm1", "status.state": "online"})))

Try it out

    [
        Lun(
            {
                "uuid": "5a24ae5b-28af-47fb-b129-5adf6cfba0a6",
                "name": "/vol/vol1/lun1",
                "svm": {"name": "svm1"},
                "status": {"state": "online"},
                "_links": {
                    "self": {
                        "href": "/api/storage/luns/5a24ae5b-28af-47fb-b129-5adf6cfba0a6"
                    }
                },
            }
        ),
        Lun(
            {
                "uuid": "c903a978-9bac-4ce9-8237-4a3ba8b13f08",
                "name": "/vol/vol1/lun2",
                "svm": {"name": "svm1"},
                "status": {"state": "online"},
                "_links": {
                    "self": {
                        "href": "/api/storage/luns/c903a978-9bac-4ce9-8237-4a3ba8b13f08"
                    }
                },
            }
        ),
        Lun(
            {
                "uuid": "7faf0a9e-0a47-4876-8318-3638d5da16bf",
                "name": "/vol/vol2/lun3",
                "svm": {"name": "svm1"},
                "status": {"state": "online"},
                "_links": {
                    "self": {
                        "href": "/api/storage/luns/7faf0a9e-0a47-4876-8318-3638d5da16bf"
                    }
                },
            }
        ),
    ]

### Retrieving details for a specific LUN

In this example, the `fields` query parameter is used to request all fields, including advanced fields, that would not otherwise be returned by default for the LUN.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="5a24ae5b-28af-47fb-b129-5adf6cfba0a6")
        resource.get(fields="**")
        print(resource)

Try it out

    Lun(
        {
            "os_type": "linux",
            "metric": {
                "duration": "PT15S",
                "latency": {"write": 0, "total": 0, "other": 0, "read": 0},
                "status": "ok",
                "throughput": {"write": 0, "total": 0, "other": 0, "read": 0},
                "iops": {"write": 0, "total": 0, "other": 0, "read": 0},
                "timestamp": "2019-04-09T05:50:15+00:00",
            },
            "class": "regular",
            "uuid": "5a24ae5b-28af-47fb-b129-5adf6cfba0a6",
            "statistics": {
                "status": "ok",
                "iops_raw": {"write": 0, "total": 3, "other": 3, "read": 0},
                "throughput_raw": {"write": 0, "total": 0, "other": 0, "read": 0},
                "timestamp": "2019-04-09T05:50:42+00:00",
                "latency_raw": {"write": 0, "total": 38298, "other": 38298, "read": 0},
            },
            "auto_delete": False,
            "space": {
                "guarantee": {"requested": False, "reserved": False},
                "used": 0,
                "size": 322163441664,
            },
            "name": "/vol/vol1/lun1",
            "svm": {
                "uuid": "6bf967fd-2a1c-11e9-b682-005056bbc17d",
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/6bf967fd-2a1c-11e9-b682-005056bbc17d"}
                },
            },
            "status": {
                "read_only": False,
                "state": "online",
                "mapped": True,
                "container_state": "online",
            },
            "serial_number": "wf0Iq+N4uck3",
            "location": {
                "volume": {
                    "uuid": "71cd0dba-2a1c-11e9-b682-005056bbc17d",
                    "name": "vol1",
                    "_links": {
                        "self": {
                            "href": "/api/storage/volumes/71cd0dba-2a1c-11e9-b682-005056bbc17d"
                        }
                    },
                },
                "logical_unit": "lun1",
            },
            "enabled": True,
            "_links": {
                "self": {
                    "href": "/api/storage/luns/5a24ae5b-28af-47fb-b129-5adf6cfba0a6?fields=**"
                }
            },
            "comment": "Data for the finance department.",
            "lun_maps": [
                {
                    "logical_unit_number": 0,
                    "_links": {
                        "self": {
                            "href": "/api/protocols/san/lun-maps/5a24ae5b-28af-47fb-b129-5adf6cfba0a6/2b9d57e1-2a66-11e9-b682-005056bbc17d"
                        }
                    },
                    "igroup": {
                        "_links": {
                            "self": {
                                "href": "/api/protocols/san/igroups/2b9d57e1-2a66-11e9-b682-005056bbc17d"
                            }
                        },
                        "name": "ig1",
                        "uuid": "2b9d57e1-2a66-11e9-b682-005056bbc17d",
                    },
                }
            ],
        }
    )

## Cloning LUNs

A clone of a LUN is an independent "copy" of the LUN that shares unchanged data blocks with the original. As blocks of the source and clone are modified, unique blocks are written for each. LUN clones can be created quickly and consume very little space initially. They can be created for the purpose of back-up, or to replicate data for multiple consumers.
Space reservations can be set for the LUN clone independent of the source LUN by setting the `space.guarantee.requested` property in a POST or PATCH request.
A LUN clone can also be set to auto-delete by setting the `auto_delete` property. If the LUN's volume is configured for automatic deletion, LUNs that have auto-delete enabled are deleted when a volume is nearly full to reclaim a target amount of free space in the volume.

## Examples

### Creating a new LUN clone

You create a new LUN clone as you create any LUN - a POST request to `/storage/luns`. Set `clone.source.uuid` or `clone.source.name` to identify the source LUN from which the clone is created. The LUN clone and its source must reside in the same volume.
The source LUN can reside in a Snapshot copy, in which case the `clone.source.name` field must be used to identify it. Add `/.snapshot/<snapshot_name>` to the path after the volume name to identify the Snapshot copy. For example `/vol/vol1/.snapshot/snap1/lun1`.
By default, new LUN clones do not inherit the QoS policy of the source LUN; a QoS policy should be set for the clone by setting the `qos_policy` property.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun()
        resource.svm.name = "svm1"
        resource.name = "/vol/vol1/lun2clone1"
        resource.clone.source.name = "/vol/vol1/lun2"
        resource.qos_policy.name = "qos1"
        resource.post(hydrate=True)
        print(resource)

### Over-writing an existing LUN's data as a clone of another

You can overwrite an existing LUN as a clone of another, using a PATCH request to `/storage/luns/{uuid}`. Set the `clone.source.uuid` or `clone.source.name` property to identify the source LUN from which the clone data is taken. The LUN clone and its source must reside in the same volume.
When used in a PATCH request, the patched LUN's data is overwritten as a clone of the source. The following properties are preserved from the patched LUN unless otherwise specified as part of the PATCH: `class`, `auto_delete`, `lun_maps`, `serial_number`, `status.state`, and `uuid`.
Persistent reservations for the updated LUN are also preserved.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="5a24ae5b-28af-47fb-b129-5adf6cfba0a6")
        resource.clone.source.name = "/vol/vol1/lun2"
        resource.patch()

## Moving LUNs between volumes

You move a LUN between volumes by using a PATCH request to `/storage/luns/{uuid}`. Set the volume portion of the fully qualified LUN path `name` property, `path.volume.uuid`, or `path.volume.name` property to a different volume than the LUN's current volume. Moving a LUN between volumes is an asynchronous activity. A successful request returns a response of 200 synchronously, which indicates that the movement has been successfully queued. The LUN object can then be further polled with a GET request to `/storage/luns/{uuid}` to monitor the status of the movement.
The `movement` sub-object of the LUN object is populated while a LUN movement is in progress and for two minutes following completion of a movement.

## Examples

### Starting a LUN movement

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="7faf0a9e-0a47-4876-8318-3638d5da16bf")
        resource.name = "/vol/vol1/lun3"
        resource.patch()

### Checking on the status of the LUN movement

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="7faf0a9e-0a47-4876-8318-3638d5da16bf")
        resource.get(fields="movement")
        print(resource)

Try it out

    Lun(
        {
            "movement": {
                "progress": {
                    "elapsed": 1,
                    "state": "preparing",
                    "volume_snapshot_blocked": False,
                    "percent_complete": 0,
                },
                "paths": {"destination": "/vol/vol1/lun3", "source": "/vol/vol2/lun3"},
            },
            "uuid": "7faf0a9e-0a47-4876-8318-3638d5da16bf",
            "name": "/vol/vol1/lun3",
            "_links": {
                "self": {"href": "/api/storage/luns/7faf0a9e-0a47-4876-8318-3638d5da16bf"}
            },
        }
    )

### Deleting a LUN

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Lun

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Lun(uuid="c903a978-9bac-4ce9-8237-4a3ba8b13f08")
        resource.delete()

## Classes

`class Lun (*args, **kwargs)`

  A LUN is the logical representation of storage in a storage area network (SAN).
  In ONTAP, a LUN is located within a volume. Optionally, it can be located within a qtree in a volume.
  A LUN can be created to a specified size using thin or thick provisioning. A LUN can then be renamed, resized, cloned, and moved to a different volume. LUNs support the assignment of a quality of service (QoS) policy for performance management or a QoS policy can be assigned to the volume containing the LUN. See the LUN object model to learn more about each of the properties supported by the LUN REST API.
  A LUN must be mapped to an initiator group to grant access to the initiator group's initiators (client hosts). Initiators can then access the LUN and perform I/O over a Fibre Channel (FC) fabric using the Fibre Channel Protocol or a TCP/IP network using iSCSI.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves LUNs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `auto_delete` * `lun_maps.*` * `movement.*` * `status.mapped` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `lun mapping show`
    - `lun move show`
    - `lun show`
    - `volume file clone show-autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a LUN.

    ### Related ONTAP commands

    - `lun delete`

    ### Learn more

    - `DOC /storage/luns`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves LUNs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `auto_delete` * `lun_maps.*` * `movement.*` * `status.mapped` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `lun mapping show`
    - `lun move show`
    - `lun show`
    - `volume file clone show-autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves LUNs.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `auto_delete` * `lun_maps.*` * `movement.*` * `status.mapped` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `lun mapping show`
    - `lun move show`
    - `lun show`
    - `volume file clone show-autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the properties of a LUN. A PATCH request can also be be used to overwrite the contents of a LUN as a clone of another, to begin movement of a LUN between volumes, and to pause and resume the movement of a LUN between volumes.

    ### Related ONTAP commands

    - `lun modify`
    - `lun move modify`
    - `lun move pause`
    - `lun move resume`
    - `lun move start`
    - `lun resize`
    - `volume file clone autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a LUN.

    ### Related ONTAP commands

    - `lun delete`

    ### Learn more

    - `DOC /storage/luns`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a LUN.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `auto_delete` * `lun_maps.*` * `movement.*` * `status.mapped` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `lun mapping show`
    - `lun move show`
    - `lun show`
    - `volume file clone show-autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the properties of a LUN. A PATCH request can also be be used to overwrite the contents of a LUN as a clone of another, to begin movement of a LUN between volumes, and to pause and resume the movement of a LUN between volumes.

    ### Related ONTAP commands

    - `lun modify`
    - `lun move modify`
    - `lun move pause`
    - `lun move resume`
    - `lun move start`
    - `lun resize`
    - `volume file clone autodelete`

    ### Learn more

    - `DOC /storage/luns`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a LUN.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the LUN.
    - `name`, `location.volume.name` or `location.volume.uuid` - Existing volume in which to create the LUN.
    - `name` or `location.logical_unit` - Base name of the LUN.
    - `os_type` - Operating system from which the LUN will be accessed. Required when creating a non-clone LUN and disallowed when creating a clone of an existing LUN. A clone's `os_type` is taken from the source LUN.
    - `space.size` - Size of the LUN. Required when creating a non-clone LUN and disallowed when creating a clone of an existing LUN. A clone's size is taken from the source LUN.

    ### Recommended optional properties

    - `qos_policy.name` or `qos_policy.uuid` - Existing traditional or adaptive QoS policy to be applied to the LUN. All LUNs should be managed by a QoS policy at the volume or LUN level.

    ### Default property values

    If not specified in POST, the follow default property values are assigned. * `auto_delete` - false

    ### Related ONTAP commands

    - `lun create`
    - `volume file clone autodelete`
    - `volume file clone create`

    ### Learn more

    - `DOC /storage/luns`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class LunSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Lun object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `auto_delete GET POST PATCH`

    This property marks the LUN for auto deletion when the volume containing the LUN runs out of space. This is most commonly set on LUN clones.
    When set to true, the LUN becomes eligible for automatic deletion when the volume runs out of space. Auto deletion only occurs when the volume containing the LUN is also configured for auto deletion and free space in the volume decreases below a particular threshold.
    This property is optional in POST and PATCH. The default value for a new LUN is false.
    There is an added cost to retrieving this property's value. It is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

  `class_ GET`

    The class of LUN. Only regular LUNs can be created using the REST API.

    Valid choices:

    - regular
    - protocol_endpoint
    - vvol
  `clone POST PATCH`

    The clone field of the lun.

  `comment GET POST PATCH`

    A configurable comment available for use by the administrator. Valid in POST and PATCH.

  `create_time GET`

    The time the LUN was created.

    Example: 2018-06-04T19:00:00.000+0000

  `enabled GET PATCH`

    The enabled state of the LUN. LUNs can be disabled to prevent access to the LUN. Certain error conditions also cause the LUN to become disabled. If the LUN is disabled, you can consult the `state` property to determine if the LUN is administratively disabled (offline) or has become disabled as a result of an error. A LUN in an error condition can be brought online by setting the `enabled` property to true or brought administratively offline by setting the `enabled` property to false. Upon creation, a LUN is enabled by default. Valid in PATCH.

  `links GET`

    The links field of the lun.

  `location GET POST PATCH`

    The location field of the lun.

  `lun_maps GET`

    The LUN maps with which the LUN is associated.
    There is an added cost to retrieving property values for `lun_maps`. They are not populated for either a collection GET or an instance GET unless explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

  `metric GET`

    The metric field of the lun.

  `movement GET POST PATCH`

    The movement field of the lun.

  `name GET POST PATCH`

    The fully qualified path name of the LUN composed of a "/vol" prefix, the volume name, the (optional) qtree name, and base name of the LUN. Valid in POST and PATCH.
    A PATCH that modifies the qtree and/or base name portion of the LUN path is considered a rename operation.
    A PATCH that modifies the volume portion of the LUN path begins an asynchronous LUN movement operation.

    Example: /vol/volume1/qtree1/lun1

  `os_type GET POST`

    The operating system type of the LUN.
    Required in POST when creating a LUN that is not a clone of another. Disallowed in POST when creating a LUN clone.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `qos_policy GET POST PATCH`

    The qos_policy field of the lun.

  `serial_number GET`

    The LUN serial number. The serial number is generated by ONTAP when the LUN is created.

  `space GET POST PATCH`

    The space field of the lun.

  `statistics GET`

    The statistics field of the lun.

  `status GET POST PATCH`

    The status field of the lun.

  `svm GET POST PATCH`

    The svm field of the lun.

  `uuid GET`

    The unique identifier of the LUN. The UUID is generated by ONTAP when the LUN is created.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412